package org.apache.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

/** Indicates an attempt to access an unknown werkz goal.
 *
 * @author <a href="mailto:bob@eng.werken.com">bob mcwhirter</a>
 * @version $Id: UnknownGoalException.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class UnknownGoalException
    extends GoalException
{
    /**
     * Generated serial version ID
     */
    private static final long serialVersionUID = 2402950819259411253L;

    /** Name of unknown goal. */
    private String goalName;

    /** Construct with an unknown goal name.
     *
     *  @param goalName The name of the unknown goal.
     */
    public UnknownGoalException( String goalName )
    {
        super( "Unknown goal \"" + goalName + "\"" );
        this.goalName = goalName;
    }

    /** Retrieve the unknown goal name.
     *
     *  @return The name of the unknown goal.
     */
    public String getGoalName()
    {
        return this.goalName;
    }
}
