package org.apache.maven.jelly.tags.jeez;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyException;
import org.apache.commons.jelly.Tag;
import org.apache.commons.jelly.TagLibrary;
import org.apache.commons.jelly.impl.DynamicTagLibrary;
import org.apache.commons.jelly.impl.TagFactory;
import org.apache.commons.jelly.impl.TagScript;
import org.apache.commons.jelly.tags.ant.AntTagLibrary;
import org.apache.maven.werkz.jelly.WerkzTagLibrary;
import org.xml.sax.Attributes;

/** Convenience taglib that puts jelly:core, jelly:werkz and jelly:ant
 *  into a single namespace.
 *
 * @author <a href="mailto:bob@eng.werken.com">bob mcwhirter</a>
 * @version $Revision: 517014 $
 */
public class JeezTagLibrary
    extends DynamicTagLibrary
{
    /** jelly:werkz taglib. */
    private TagLibrary werkzTagLib = new WerkzTagLibrary();

    /** jelly:ant taglib. */
    private AntTagLibrary antTagLib = new AntTagLibrary();

    /**
     * Create a script from the element and the attributes.
     * This method will check for 'tagdef' and 'target' tags, and try to create
     * an instance of these tags first.
     *
     * Failing that it tries to create a werkz tag script followed by an ant
     * 'custom tag script' (i.e. one for filescanner or setProperty).
     *
     * If all else fails, it creates a TagScript from a factory that creates a script
     * from either a Jeez tag, or an Ant tag
     * @see org.apache.commons.jelly.TagLibrary#createTagScript(java.lang.String, org.xml.sax.Attributes)
     */
    public TagScript createTagScript( final String name, Attributes attrs )
        throws JellyException
    {

        if ( name.equals( "tagdef" ) )
        {
            return new TagScript( new TagFactory()
            {
                public Tag createTag( String name, Attributes attributes )
                {
                    return new TagDefTag( JeezTagLibrary.this );
                }
            } );
        }
        if ( name.equals( "target" ) )
        {
            return new TagScript( new TagFactory()
            {
                public Tag createTag( String name, Attributes attributes )
                {
                    return new TargetTag();
                }
            } );
        }

        TagScript script = werkzTagLib.createTagScript( name, attrs );
        if ( script == null )
        {
            script = antTagLib.createCustomTagScript( name, attrs );
            if ( script == null )
            {
                return new TagScript( new TagFactory()
                {
                    public Tag createTag( String name, Attributes attributes )
                        throws JellyException
                    {
                        // lets try create a dynamic tag first
                        Tag tag = JeezTagLibrary.this.createTag( name, attributes );
                        if ( tag != null )
                        {
                            return tag;
                        }
                        else
                        {
                            return antTagLib.createTag( name, attributes );
                        }
                    }
                } );
            }
        }
        return script;
    }
}
