package org.apache.maven.jelly.tags.jeez;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyException;
import org.apache.commons.jelly.impl.TagScript;
import org.apache.maven.jelly.tags.werkz.MavenAttainGoalTag;
import org.apache.maven.jelly.tags.werkz.MavenGoalTag;
import org.xml.sax.Attributes;

/** Replacement for Jelly's <code>JeezTagLibrary</code>.
 *
 *  @author <a href="mailto:bob@eng.werken.com">bob mcwhirter</a>
 *
 *  @version $Id: MavenJeezTagLibrary.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class MavenJeezTagLibrary
    extends JeezTagLibrary
{
    // ------------------------------------------------------------
    //     org.apache.commons.jelly.tags.jeez.JeezTagLibrary
    // ------------------------------------------------------------

    /** Create a <code>TagScript</code> based upon an element's
     *  name and attributes.
     *
     *  @param name The name.
     *  @param attrs The attributes.
     *  @return Generated <code>TagScript</code> from an elements
     *   name and attributes.
     *
     *  @throws JellyException If an error occurs while attempting to
     *          create the script.
     */

    public TagScript createTagScript( String name, Attributes attrs )
        throws JellyException
    {
        if ( "goal".equals( name ) )
        {
            return TagScript.newInstance( MavenGoalTag.class );
        }
        else if ( "attainGoal".equals( name ) )
        {
            return TagScript.newInstance( MavenAttainGoalTag.class );
        }

        // Otherwise, act like nothing is different.
        return super.createTagScript( name, attrs );
    }
}
