package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;

/**
 * Concat a set of files together into a single file.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: ConcatTag.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class ConcatTag
    extends MavenTag
{
    /** Output file. */
    private File outputFile;

    /** List of file to concatenate together. */
    private ArrayList files = new ArrayList();

    /** Set output file. */
    public void setOutputFile( File outputFile )
    {
        this.outputFile = outputFile;
    }

    /** Add a file to the list of files of be concatenated. */
    public void addFile( File file )
    {
        files.add( file );
    }

    /**
     * Perform functionality provided by the tag.
     *
     * @throws JellyTagException If there is an error while concatenating the file.
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        try
        {
            // Make sure we have an output file.
            checkAttribute( outputFile, "outputFile" );

            // Collect all the input files by invoking the body.
            invokeBody( output );

            // If the directory where the output file is going to land
            // doesn't exists then create it.
            File outputFileDirectory = outputFile.getParentFile();

            if ( !outputFileDirectory.exists() )
            {
                outputFileDirectory.mkdirs();
            }

            FileOutputStream fos = new FileOutputStream( outputFile );

            // We should now have all the files we want to concat so
            // lets do it.
            for ( Iterator i = files.iterator(); i.hasNext(); )
            {
                File f = (File) i.next();
                FileInputStream in = new FileInputStream( f );

                int count;
                byte[] b = new byte[512];
                while ( ( count = in.read( b ) ) > 0 ) // blocking read
                {
                    fos.write( b, 0, count );
                }

                in.close();
            }

            fos.flush();
            fos.close();
        }
        catch ( IOException e )
        {
            throw new JellyTagException( e );
        }
    }
}
