package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;

/**
 * A Maven Jelly tag that attempts to retrieve a property from the MavenJellyContext
 * context and uses the provided default value in the event there is no valid value
 * retrieved using the key name provided. You may also optionally provide the name
 * you would like to give the resultant property in the MavenJellyContext.
 *
 * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
 *
 */
public class PropertyTag
    extends BaseTagSupport
{
    private String name;

    private String defaultValue;

    private String var;

    public void setName( String name )
    {
        this.name = name;
    }

    public void setDefaultValue( String defaultValue )
    {
        this.defaultValue = defaultValue;
    }

    public void setVar( String var )
    {
        this.var = var;
    }

    /* (non-Javadoc)
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        checkAttribute( name, "name" );

        checkAttribute( defaultValue, "defaultValue" );

        String property = (String) getContext().getVariable( name );

        if ( property == null )
        {
            property = defaultValue;
        }

        if ( var != null )
        {
            getContext().setVariable( var, property );
        }
        else
        {
            getContext().setVariable( name, property );
        }
    }
}
