package org.apache.maven.repository;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.maven.MavenException;
import org.apache.maven.project.Project;

/**
 *  This will do until wagon debuts.
 * 
 * @author <a href="mailto:brett@apache.org">Brett Porter</a> 
 * @version $Id: ArtifactTypeHandler.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public interface ArtifactTypeHandler
{
    /**
     * Map an artifact to a repository path.
     * 
     * @param project the project for the artifact
     * @param type  The type of the artifact 
     * @param version  The version of the artifact 
     * @return the path
     */
    public String constructRepositoryFullPath( String type, Project project, String version )
        throws MavenException;

    /**
     * Map an artifact to a repository directory path.
     * 
     * @param project the project for the artifact
     * @param type  The type of the artifact 
     * @return the path
     */
    public String constructRepositoryDirectoryPath( String type, Project project )
        throws MavenException;
}
