package org.apache.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import junit.framework.TestCase;

import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

/**
 * Tests to check JAXP is correctly configured and classes are being loaded
 */
public class JAXPTest
    extends TestCase
{

    /**
     * Constructor for JAXPTest.
     * @param name test name
     */
    public JAXPTest( String name )
    {
        super( name );
    }

    /**
     * test the jaxp property for the sax parser (org.xml.sax.parser)
     * returns the piccolo parser
     * @throws Exception if any problems occur
     */
    public void testSAXParser()
        throws Exception
    {
        // the sax parser should be piccolo
        SAXParserFactory factory = SAXParserFactory.newInstance();
        factory.setNamespaceAware( true );
        SAXParser parser = factory.newSAXParser();
        assertTrue( "Wrong sax parser", parser.getClass().getName().startsWith( "com.bluecast.xml." ) );
    }

    /**
     * test the jaxp property for the XML Reader (org.xml.sax.driver)
     * returns the correct XMLReader
     * @throws Exception if any problems occur
     */
    public void testXMLReader()
        throws Exception
    {
        XMLReader reader = XMLReaderFactory.createXMLReader();
        assertTrue( "Wrong xml reader", reader.getClass().getName().startsWith( "com.bluecast.xml." ) );
    }

    /**
     * Test that the DocumentBuilderFactory comes from Xerces
     */
    public void testDocumentBuilderFactory()
        throws Exception
    {
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        factory.setNamespaceAware( true );
        DocumentBuilder builder = factory.newDocumentBuilder();
        assertTrue( "Wrong document builder", builder.getClass().getName().startsWith( "org.apache.xerces.jaxp." ) );
    }
}
