package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import org.apache.maven.project.Dependency;
import org.apache.maven.project.Project;

/**
 * @author  Ben Walding
 * @version $Id: DependencyResolverTestData.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class DependencyResolverTestData
{

    public static List getTestSimple1()
    {
        List results = new ArrayList();
        results.add( createProject( "j:j", "n:n" ) );
        results.add( createProject( "n:n", "e:e" ) );
        results.add( createProject( "e:e", "b:b" ) );
        results.add( createProject( "b:b", "" ) );
        return results;
    }

    public static List getTestSimple2()
    {
        List results = new ArrayList();
        results.add( createProject( "ox:ox", "nf:nf" ) );
        results.add( createProject( "nf:nf", "ow:ow" ) );
        results.add( createProject( "ow:ow", "br:br" ) );
        results.add( createProject( "br:br", "ck:ck" ) );
        results.add( createProject( "ck:ck", "ui:ui" ) );
        results.add( createProject( "ui:ui", "eq:eq" ) );
        results.add( createProject( "eq:eq", "th:th" ) );
        results.add( createProject( "th:th", "" ) );
        results.add( createProject( "ox:ox", "nf:nf" ) );
        results.add( createProject( "ox:ox", "nf:nf" ) );
        return results;
    }

    public static List getTestSimple3()
    {
        List results = new ArrayList();
        results.add( createProject( "ox:ox", "nf:nf" ) );
        results.add( createProject( "ui:ui", "eq:eq" ) );
        results.add( createProject( "ow:ow", "br:br" ) );
        results.add( createProject( "ck:ck", "ui:ui" ) );
        results.add( createProject( "nf:nf", "ow:ow" ) );
        results.add( createProject( "eq:eq", "th:th" ) );
        results.add( createProject( "br:br", "ck:ck" ) );
        results.add( createProject( "th:th", "" ) );
        return results;
    }

    public static List getTestCycle()
    {
        List results = new ArrayList();
        results.add( createProject( "a:a", "b:b" ) );
        results.add( createProject( "b:b", "c:c" ) );
        results.add( createProject( "c:c", "a:a" ) );
        return results;
    }

    public static List getTestComplex()
    {
        List results = new ArrayList();
        results.add( createProject( "tyre:tyre", "rubber:rubber" ) );
        results.add( createProject( "car:car", "petrol:petrol,driver:driver,key:key,tyre:tyre" ) );
        results.add( createProject( "car:car", "" ) );
        results.add( createProject( "driver:driver", "wallet:wallet,license:license,key:key" ) );
        results.add( createProject( "driver:driver", "beer:beer" ) );
        results.add( createProject( "beer:beer", "water:water,hops:hops,malt:malt" ) );
        results.add( createProject( "hops:hops", "" ) );
        return results;
    }

    private static Project createProject( String id )
    {
        Project p = new Project();
        p.setId( id );
        return p;
    }

    private static Dependency createDependency( String id )
    {
        Dependency d = new Dependency();
        d.setId( id );
        return d;
    }

    private static Project createProject( String id, String dependencies )
    {
        StringTokenizer depToks = new StringTokenizer( dependencies, ",", false );
        Project p = createProject( id );
        while ( depToks.hasMoreTokens() )
        {
            String token = depToks.nextToken();
            Dependency d = createDependency( token );
            p.addDependency( d );
        }
        return p;
    }
}
