package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.Arrays;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import junit.framework.TestCase;

/**
 * Test InsertionOrderedSet.
 *
 * @author <a href="mailto:brett@apache.org">Brett Porter</a>
 * @version $Id: InsertionOrderedSetTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class InsertionOrderedSetTest
    extends TestCase
{
    private Set set = new InsertionOrderedSet();

    private static final String STRING_1 = "zzz";

    private static final String STRING_2 = "qqq";

    private static final String STRING_3 = "www";

    private static final HashSet REMOVED_ELEMENT_SET = new HashSet( Arrays.asList( new String[] { STRING_1, STRING_3 } ) );

    private static final HashSet OUTPUT_SET = new HashSet( Arrays
        .asList( new String[] { STRING_1, STRING_2, STRING_3 } ) );

    private static final List INPUT_SET = Arrays.asList( new String[] { STRING_1, STRING_2, STRING_1, STRING_3 } );

    public void setUp()
        throws Exception
    {
    }

    public void testAdd()
    {
        set.add( STRING_1 );
        set.add( STRING_2 );
        set.add( STRING_1 );
        set.add( STRING_3 );

        assertEquals( OUTPUT_SET, set );
    }

    public void testAddAll()
    {
        set.addAll( INPUT_SET );
        assertEquals( OUTPUT_SET, set );
    }

    public void testConstructor()
    {
        Set set = new InsertionOrderedSet( INPUT_SET );
        assertEquals( OUTPUT_SET, set );
    }

    public void testRemove()
    {
        set.addAll( INPUT_SET );
        set.remove( STRING_2 );
        assertEquals( REMOVED_ELEMENT_SET, set );
    }

    public void testIterator()
    {
        set.addAll( INPUT_SET );

        Iterator i = set.iterator();
        assertEquals( STRING_1, i.next() );
        assertEquals( STRING_2, i.next() );
        assertEquals( STRING_3, i.next() );
    }

    public void testIteratorRemove()
    {
        set.addAll( INPUT_SET );

        Iterator i = set.iterator();
        assertEquals( STRING_1, i.next() );
        assertEquals( STRING_2, i.next() );
        i.remove();
        assertEquals( STRING_3, i.next() );

        assertEquals( REMOVED_ELEMENT_SET, set );
    }

}
