package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.List;

import junit.framework.TestCase;

/**
 * @author Ben Walding
 *
 */
public class StringToolTest
    extends TestCase
{
    private StringTool cst;

    public StringToolTest( String name )
    {
        super( name );
    }

    public void setUp()
    {
        cst = new StringTool();
    }

    public void tearDown()
    {
        cst = null;
    }

    public void testSplitStringAtLastDelim()
    {
        testSplitStringAtLastDelim( "org.apache.maven.StringTool", ".", "org.apache.maven", "StringTool" );
        testSplitStringAtLastDelim( "org/apache/maven/StringTool.java", ".", "org/apache/maven/StringTool", "java" );
        testSplitStringAtLastDelim( "org.apache.maven.StringTool", "|", "org.apache.maven.StringTool", "" );
        testSplitStringAtLastDelim( null, null, null, null );

    }

    public void testSplitStringAtLastDelim( String input, String delim, String s0, String s1 )
    {
        List result = cst.splitStringAtLastDelim( input, delim );
        String f = "splitStringAtLastDelim(" + input + "," + delim + ")";
        assertEquals( f + "[0]", s0, result.get( 0 ) );
        assertEquals( f + "[1]", s1, result.get( 1 ) );
    }

}
